%%%%%%%%%%%%%%%%% Example 8.2(c) %%%%%%%%%%%%%%%%
%   Discrete-Time Control Problems using        %
%       MATLAB and the Control System Toolbox   %
%   by J.H. Chow, D.K. Frederick, & N.W. Chbat  %
%         Brooks/Cole Publishing Company        %
%                September 2002                 %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   ----  Step responses with PI control  ----
%
clear
disp('Example 8.2(c)')

%--- find best KP for fixed KI value
%
Ts = 0.1;			                % sampling period
Gp_s = tf(4,conv([2 1],[0.5 1]));   % continuous process
H_s = tf(1,[0.05 1]);		        % continuous sensor
Gp_z = c2d(Gp_s,Ts,'zoh');	        % discrete plant (no sensor)
HGp_z = c2d(H_s*Gp_s,Ts,'zoh');     % discrete plant + sensor

KP = 0.563; 
KI = 0.50;  	                    % Mo = 10.002 (10 pct step OS for ref input)
Gc  = KP*tf([1+KI*Ts  -1],[1 -1],Ts); % PI controller

dtime = 0:Ts:8;
%------- reference input - CL transfer fcn
Tref_z = Gp_z*Gc/(1+HGp_z*Gc)
Tref_z = minreal(Tref_z);           % remove pole-zero cancellations
y_ref = step(Tref_z,dtime);

%------- disturbance input - CL transfer fcn
Tdist_z = Gp_z/(1+HGp_z*Gc)
Tdist_z = minreal(Tdist_z);         % remove pole-zero cancellations
y_dist = step(Tdist_z,dtime);

%------- plot responses ----------
figure 
hold on
plot(dtime,y_ref,'bo');grid
plot(dtime,y_dist,'r+')
hold off
xlabel('Time (s)')
ylabel('Amplitude')
title(['Example 8.2(c) - Responses to step reference (o) and ',...
       'disturbance(+) inputs'])
text('Units','norm','Pos',[0.5,0.76],'Str','reference')
text('Units','norm','Pos',[0.37,0.15],'Str','disturbance')
text('Units','norm','Pos',[0.8,0.50],'Str',['KP = ',num2str(KP)])
text('Units','norm','Pos',[0.8,0.40],'Str',['KI = ',num2str(KI)])
hold off

%------ steady state values
y_ref_ss = y_ref(end)
y_dist_ss = y_dist(end)

%----- compute prcent OS
pct_OS = 100 * (max(y_ref)/y_ref_ss - 1)
%%%%%%%%%%