function  y = rpole2k(p,res,dtime)
%RPOLE2K y = rpole2k(p,res,dtime) 
%        Performs inverse z transform for a real pole
%        and generates a discrete-time function. 
%Inputs: p - real pole
%        res - residue of G(z)/z at the real pole
%        dtime - discrete-time vector [0 1 2...kmax]
%Output: y - discrete-time response vector
%
%        The response is computed as y(k) = res * p^k
%               where k is the discrete-time variable

%%%%%%%%%%%%%%%%%%% rpole2k.m %%%%%%%%%%%%%%%%%%%
%   Discrete-Time Control Problems using        %
%       MATLAB and the Control System Toolbox   %
%   by J.H. Chow, D.K. Frederick, & N.W. Chbat  %
%         Brooks/Cole Publishing Company        %
%                September 2002                 %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

y = 0*dtime;
y(1) = res;
for kk = 2:length(dtime),
   y(kk) = y(kk-1)*p;
end
%----- remove any very small imaginary parts
y = real(y);
%%%%%%%%%%